Imports Microsoft.VisualBasic
Imports System
Imports Microsoft.SharePoint

Namespace MSDN.SPTips.Task
	''' <summary>
	''' SharePoint server dependent implementation of ITaskRepository
	''' </summary>
	Public Class SPTaskRepository
		Implements ITaskRepository

		Private _config As ITaskRepositoryConfig

		Public Sub New()
			Me.New(New StubbedTaskRepositoryConfig())
			' in a production level application, use an IoC container
		End Sub

		Public Sub New(ByVal config As ITaskRepositoryConfig)
			_config = config
		End Sub

		Public Function GetTasks() As TaskCollection Implements ITaskRepository.GetTasks

			Dim tasks As New TaskCollection()

			' If you are not creating tests and just want to get a list
			' from the current Web, you can do it this way:
			' SPListItemCollection spTasks =
			' SPContext.Current.Web.Lists[_config.ListName].Items;

			' However, this doesn't work well for creating testable code. 
			' Therefore, here is an approach you can take that will work 
			' both from MSTest and when the code runs in the context of a 
			' SharePoint Web:
			' first, get the site collection
			Using site As New SPSite(_config.SiteUrl)
				' then get the root web of the site collection
				Using web As SPWeb = site.RootWeb
					' finally, get the list item collection from the Web
					Dim spTasks As SPListItemCollection = web.Lists(_config.ListName).Items
					For Each spTask As SPListItem In spTasks
						tasks.Add(New Task With {.TaskName = CStr(spTask(_config.TaskNameFieldName)), .PercentComplete = CDbl(spTask(_config.PercentCompleteFieldName))})
					Next spTask
				End Using
			End Using

			Return tasks
		End Function
	End Class
End Namespace
