Imports Microsoft.VisualBasic
Imports System

Imports Rhino.Mocks
Imports Microsoft.VisualStudio.TestTools.UnitTesting

Imports MSDN.SPTips.Task
Imports MSDN.SPTips.WebPart.Presentation

Namespace SPTips.TaskService.Tests
'    
'     * The tests use RhinoMocks open source framework for interaction-based testing.
'     * To read more about it go to: http://ayende.com/projects/rhino-mocks.aspx 
'    

	<TestClass> _
	Public Class TaskPresenterTests

		<TestMethod> _
		Public Sub InitializeView_ShouldCallToRepositoryToRetrieveTasks()
			Dim mockTaskRepository = MockRepository.GenerateMock(Of ITaskRepository)()
			Dim mockTaskView = MockRepository.GenerateMock(Of IView)()

			' expect that the repository's GetTasks method is called
			Dim tasks = New TaskCollection()
			mockTaskRepository.Expect(Function(x) x.GetTasks()).Return(tasks)

			' configure the Presenter with its dependencies
			Dim presenter = New Presenter(mockTaskView, mockTaskRepository)

			' run the object under test
			presenter.InitializeView()

			' verify that the expectations have been met
			mockTaskRepository.VerifyAllExpectations()
		End Sub

		<TestMethod> _
		Public Sub InitializeView_WhenTasksRetrievedPassTasksToViewForRendering()
			Dim mockTaskRepository = MockRepository.GenerateMock(Of ITaskRepository)()
			Dim mockTaskView = MockRepository.GenerateMock(Of IView)()

			' we stub the call to repository, since we don't want to verify it again
			' it has been done in the previous test            
			Dim tasks = New TaskCollection()
			mockTaskRepository.Stub(Function(x) x.GetTasks()).Return(tasks)

			' in this test we verify that the tasks are properly passed to the view from the presenter            
			mockTaskView.Expect(Function(x) x.Tasks = tasks)

			' configure the Presenter with its dependencies
			Dim presenter = New Presenter(mockTaskView, mockTaskRepository)

			' run the object under test
			presenter.InitializeView()

			mockTaskView.VerifyAllExpectations()
		End Sub
	End Class
End Namespace